<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/dist.git

return [

	// D
	'dist_description' => 'Jeu de squelettes distribué avec SPIP 3.',
	'dist_slogan' => 'Squelettes par défaut de SPIP 3',
];
